Seperated data, controller, display layers
-------

**Description:**

The application should sepperate data, controller, and display layers in order to make your
application more clear and understandable in terms of abstraction due to sepperation.

Whenever your application is more organized and abstracted it is much easier to implement 
less flawed security controlls.

 
**Solution:**

Make sure your different type of data layers are seperated in your application.

The sepperation of these differnt layers is also know as a design pattern which goes 
by the name MVC (model, view, controller).
